<?php
namespace Modules\Parametro\Controllers; 

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification; 
use Modules\Parametro\Services\Gop00100ParametroOrcamentoOperacionalService;

class Gop00100OrcamentoOperacionalController extends \Teknisa\GER\Controllers\TeknisaCrud{
    
    protected $crudService;
    protected $connection;
    protected $environment;
    
    public function __construct($crudService, ParameterBag $parameterBag, $connection, $environment, $service) {
        $this->connection = $connection;
        $this->environment = $environment;
        parent::__construct($crudService, $parameterBag);
        $this->service = $service;
    }
    public function atualizaFilial(DTO\Request $request, DTO\Response $response){
        
        $rows    = $request->getParameter("dataset");
        
        if($rows != null){
            
            try{
                foreach($rows as $row){
                    if(!empty($row["NMFILIAL"])){
                        foreach ($row["NMFILIAL"] as $value) {
                            $stmt = $this->connection->prepare(
                            "UPDATE FILIAL
                                    SET
                                        NRMESREAJCONTR     = NVL(:P_NRMESREAJCONTR_NOVO,NRMESREAJCONTR),
                                        IDCONSAFORCFIL     = NVL(:P_IDCONSAFORCFIL_NOVO, IDCONSAFORCFIL),
                                        VRPEORCALERTFIL    = NVL(:P_VRPEORCALERTFIL_NOVO, VRPEORCALERTFIL),
                                        VRPEORCBLOQFIL     = NVL(:P_VRPEORCBLOQFIL_NOVO, VRPEORCBLOQFIL),
                                        IDCALCOMESTORC     = NVL(:P_IDCALCOMESTORC_NOVO, IDCALCOMESTORC),
                                        NRDIAINIORCAGOP    = NVL(:P_NRDIAINIORCAGOP_NOVO, NRDIAINIORCAGOP),
                                        CDOPERULTATU    = :P_CDOPERULTATU
                                    WHERE
                                        CDFILIAL = :P_CDFILIAL"
                            );
                            $stmt->execute(
                                array(
                                    'P_NRMESREAJCONTR_NOVO'  => $row["NRMESREAJCONTR"],
                                    'P_IDCONSAFORCFIL_NOVO'  => $row["IDCONSAFORCFIL"],
                                    'P_VRPEORCALERTFIL_NOVO' => $row["VRPEORCALERTFIL"],
                                    'P_VRPEORCBLOQFIL_NOVO'  => $row["VRPEORCBLOQFIL"],
                                    'P_IDCALCOMESTORC_NOVO'  => $row["IDCALCOMESTORC"],
                                    'P_NRDIAINIORCAGOP_NOVO' => $row["NRDIAINIORCAGOP"],
                                    'P_CDOPERULTATU' => $this->environment->getCdOperador(),
                                    'P_CDFILIAL' => $value
                                )
                            );
                        }
                    }
                   
                }
            }catch(\Exception $ex){
                    $response->setError(new Error($ex->getMessage(), 500));
            }
        }

    }
    
    public function updateItensOperacionais(DTO\Request $request, DTO\Response $response) {
        $rows = $request->getParameter("row");
        $this->service->beginTransaction();
        
        try {
            foreach($rows as $row) {
                if(!$row["__isSelected"]) {
                    $idCheck = "N";    
                }else {
                    $idCheck = "S";
                }
                
                $params = array(
                    "P_IDCHECK"             => $idCheck,
                    "P_NRITEMOPERACIONAL"   => $row["NRITEMOPERACIONAL"]
                );
                
                $this->service->updateOrcamento($params);
            }
            $this->service->commit();
            
        } catch(Exception $ex) {
            $this->service->rollback();
            throw $e;
        }
    }
    
    public function itensOperac(DTO\Request $request, DTO\Response $response) {
        $rows = $request->getParameter("row");
        
        try{
            $stmt = $this->connection->prepare("
                SELECT 
                    IT.NRITEMOPERACIONAL,
                    IT.IDTIPOORCAOP,
                    IT.IDCHECK
                FROM ITEMOPERACIONAL IT");
            $stmt->execute();
            $return = $stmt->fetchAll();
            
            if(count($return) == 0) {
                $this->insertItens($rows);
            }
            
            $response->addDataSet(new DataSet("ROW", $return));
        }catch(Exception $e) {
            throw $e;
        }
    }
    
    public function insertItens($rows) {
        $this->service->beginTransaction();
        $idCheck = 'S';
        
        try{
            foreach($rows as $row) {
                if($row["NMITORCAMENTO"] === "Faturamento") {
                    $idTipoOrca = 'FATURAMENTO';
                    $nrItemOperacional = 0;
                }
                else if($row["NMITORCAMENTO"] === "Imposto") {
                    $idTipoOrca = "IMPOSTO";
                    $nrItemOperacional = 1;
                }
                else if($row["NMITORCAMENTO"] === "Consumo") {
                    $idTipoOrca = "CONSUMO";
                    $nrItemOperacional = 2;
                }
                else if($row["NMITORCAMENTO"] === "Mão de Obra") {
                    $idTipoOrca = "MAOOBRA";
                    $nrItemOperacional = 3;
                }
                else if($row["NMITORCAMENTO"] === "Taxa Administrativa") {
                    $idTipoOrca = "TAXAADM";
                    $nrItemOperacional = 4;
                }
                else if($row["NMITORCAMENTO"] === "Despesa Matriz") {
                    $idTipoOrca = "DESPMATRIZ";
                    $nrItemOperacional = 5;
                }
                else if($row["NMITORCAMENTO"] === "Despesa Diversas") {
                    $idTipoOrca = "DESPDIVERSA";
                    $nrItemOperacional = 6;
                }
                else if($row["NMITORCAMENTO"] === "Despesa Lançamento de Entrada") {
                    $idTipoOrca = "DESPENTRADA";
                    $nrItemOperacional = 7;
                }
                else if($row["NMITORCAMENTO"] === "Imposto a Recuperar") {
                    $idTipoOrca = "IMPOSTOARECUPERAR";
                    $nrItemOperacional = 8;
                }
                else if($row["NMITORCAMENTO"] === "Imposto Sobre o Lucro") {
                    $idTipoOrca = "IMPOSTOSOBLUCRO";
                    $nrItemOperacional = 9;
                }
                else if($row["NMITORCAMENTO"] === "Investimento") {
                    $idTipoOrca = "INVESTIMENTO";
                    $nrItemOperacional = 10;
                }
                else if($row["NMITORCAMENTO"] === "Depreciação") {
                    $idTipoOrca = "DEPRECIACAO";
                    $nrItemOperacional = 11;
                }
                
                $params = array(
                    "P_NRITEMOPERACIONAL"   => $nrItemOperacional,
                    "P_IDCHECK"             => $idCheck,
                    "P_IDTIPOORCAOP"        => $idTipoOrca
                );
                
                $this->service->insertItensOp($params);
            }
            $this->service->commit();
        }catch(Exception $e) {
            $this->service->rollback();
            throw $e;
        }
    }
}